@@ -5,7 +5,7 @@
  
   Copyright (c) 2000 Dug Song <dugsong@monkey.org>
   
-  $Id: asn1.h,v 1.1 2000/05/16 17:31:13 dugsong Exp $
+  $Id: asn1.h,v 1.2 2000/11/15 17:54:46 dugsong Exp $
 */
 
 #ifndef ASN1_H
@@ -15,8 +15,8 @@
 #define ASN1_STRING	4
 #define ASN1_SEQUENCE	16
 
-int	asn1_type(u_char **buf);
-int	asn1_len(u_char **buf);
+int	asn1_type(buf_t buf);
+int	asn1_len(buf_t buf);
 
 #endif /* ASN1_H */
 
