@@ -5,7 +5,7 @@
   
   Copyright (c) 2000 Dug Song <dugsong@monkey.org>
  
-  $Id: decode_cvs.c,v 1.3 2000/06/17 16:29:50 dugsong Exp $
+  $Id: decode_cvs.c,v 1.5 2000/11/15 05:54:51 dugsong Exp $
 */
 
 #include "config.h"
@@ -13,6 +13,7 @@
 #include <sys/types.h>
 #include <stdio.h>
 #include <string.h>
+#include "buf.h"
 #include "decode.h"
 
 /* stolen from CVS scramble.c */
@@ -36,32 +37,38 @@ static u_char cvs_shifts[] = {
 };
 
 int
-decode_cvs(u_char *buf, int len)
+decode_cvs(u_char *buf, int len, u_char *obuf, int olen)
 {
-	char *p;
-	int i, linenum = 0;
-	
-	Buf[0] = '\0';
-	
-	if (strip_lines(buf, 5) != 5 || strncmp(buf, "BEGIN ", 6) != 0)
+	struct buf *line, inbuf, outbuf;
+	u_char *p;
+	int i, n;
+
+	buf_init(&inbuf, buf, len);
+	buf_init(&outbuf, obuf, olen);
+
+	if (buf_cmp(&inbuf, "BEGIN ", 6) != 0)
 		return (0);
-	
-	for (p = strtok(buf, "\n"); p != NULL; p = strtok(NULL, "\n")) {
-		linenum++;
-		strlcat(Buf, p, sizeof(Buf));
+
+	for (n = 0; n < 5 && (i = buf_index(&inbuf, "\n", 1)) != -1; n++) {
+		line = buf_tok(&inbuf, NULL, i + 1);
+		line->base[line->end - 1] = '\0';
+
+		p = buf_ptr(line);
+		buf_putf(&outbuf, "%s", p);
 		
-		if (linenum == 4) {
+		if (n == 3) {
 			if (p[0] != 'A')
 				return (0);
-			for (i = 1; i < sizeof(cvs_shifts) && p[i] != '\0';
-			     i++)
-				p[i] = cvs_shifts[(u_char)(p[i])];
-			strlcat(Buf, " [", sizeof(Buf));
-			strlcat(Buf, p + 1, sizeof(Buf));
-			strlcat(Buf, "]", sizeof(Buf));
+
+			for (i = 1; i < sizeof(cvs_shifts) - 1 && p[i]; i++)
+				p[i] = cvs_shifts[p[i]];
+			
+			buf_putf(&outbuf, " [%s]", p + 1);
 		}
-		strlcat(Buf, "\n", sizeof(Buf));
+		buf_put(&outbuf, "\n", 1);
 	}
-	return (strlen(Buf));
+	buf_end(&outbuf);
+	
+	return (buf_len(&outbuf));
 }
 
