@@ -7,38 +7,38 @@
   
   Copyright (c) 2000 Dug Song <dugsong@monkey.org>
  
-  $Id: decode_mountd.c,v 1.3 2000/06/14 07:14:53 dugsong Exp $
+  $Id: decode_mountd.c,v 1.6 2000/12/15 20:13:29 dugsong Exp $
 */
 
 #include "config.h"
 
-#include <sys/types.h>
 #include <sys/param.h>
+#include <sys/types.h>
 #include <rpc/rpc.h>
-#include <rpcsvc/mount.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#include "buf.h"
+#include "mount.h"
 #include "rpc.h"
 #include "decode.h"
 
 int
-decode_mountd(u_char *buf, int len)
+decode_mountd(u_char *buf, int len, u_char *obuf, int olen)
 {
+	XDR xdrs;
+	struct buf outbuf;
 	struct rpc_msg msg;
 	struct xid_map *xm;
-	XDR xdrs;
-	char *p, *dir, *fh;
 	struct fhstatus fhstat;
+	char *p, *dir;
 	int i, hdrlen;
-	
-	memset(&msg, 0, sizeof(msg));
+
+	buf_init(&outbuf, obuf, olen);
 	
 	if ((hdrlen = rpc_decode(buf, len, &msg)) == 0)
 		return (0);
 
-	Buf[0] = '\0';
-	
 	if (msg.rm_direction == CALL &&
 	    msg.rm_call.cb_prog == MOUNTPROG &&
 	    msg.rm_call.cb_proc == MOUNTPROC_MNT) {
@@ -58,16 +58,16 @@ decode_mountd(u_char *buf, int len)
 				      XDR_DECODE);
 			if (xdr_fhstatus(&xdrs, &fhstat)) {
 				if (fhstat.fhs_status == 0) {
-					snprintf(Buf, sizeof(Buf), "%s [",
+					buf_putf(&outbuf, "%s [",
 						 (char *)xm->data);
-					fh = Buf + strlen(Buf);
+					
 					p = fhstat.fhstatus_u.fhs_fhandle;
 					
-					for (i = 0; i < FHSIZE; i++)
-						sprintf(fh + (i * 3), "%.2x ",
-							p[i] & 0xff);
-					fh[(i * 3) - 1] = '\0';
-					strlcat(Buf, "]\n", sizeof(Buf));
+					for (i = 0; i < FHSIZE; i++) {
+						buf_putf(&outbuf, "%.2x ",
+							 p[i] & 0xff);
+					}
+					buf_put(&outbuf, "]\n", 2);
 				}
 			}
 			xdr_destroy(&xdrs);
@@ -75,5 +75,7 @@ decode_mountd(u_char *buf, int len)
 		free(xm->data);
 		memset(xm, 0, sizeof(*xm));
 	}
-	return (strlen(Buf));
+	buf_end(&outbuf);
+	
+	return (buf_len(&outbuf));
 }
