@@ -5,7 +5,7 @@
   
   Copyright (c) 2000 Dug Song <dugsong@monkey.org>
  
-  $Id: decode_ospf.c,v 1.3 2000/06/14 16:16:00 dugsong Exp $
+  $Id: decode_ospf.c,v 1.5 2000/12/15 20:16:58 dugsong Exp $
 */
 
 #include "config.h"
@@ -16,16 +16,16 @@
 #include "decode.h"
 
 int
-decode_ospf(u_char *buf, int len)
+decode_ospf(u_char *buf, int len, u_char *obuf, int olen)
 {
 	if (len < 25)
 		return (0);
 	
-	if (ntohs(*(u_short *)&buf[14]) != 1)
+	if (pntohs(buf + 14) != 1)
 		return (0);
 	
 	buf[24] = '\0';
 	
-	return (snprintf(Buf, sizeof(Buf), "%s\n", buf + 16));
+	return (snprintf(obuf, olen, "%s\n", buf + 16));
 }
 
