@@ -5,7 +5,7 @@
   
   Copyright (c) 2000 Dug Song <dugsong@monkey.org>
  
-  $Id: decode_smb.c,v 1.2 2000/06/14 16:16:00 dugsong Exp $
+  $Id: decode_smb.c,v 1.3 2000/11/06 14:08:42 dugsong Exp $
 */
 
 #include "config.h"
@@ -27,14 +27,14 @@ struct smbhdr {
 };
 
 int
-decode_smb(u_char *buf, int len)
+decode_smb(u_char *buf, int len, u_char *obuf, int olen)
 {
 	struct smbhdr *smb;
 	int i, j, k;
 	u_char *p, *q, *end;
 	char *user, *pass;
 	
-	Buf[0] = '\0';
+	obuf[0] = '\0';
 	
 	/* Skip NetBIOS session request. */
 	if (len < 4 || buf[0] != 0x81) return (0);
@@ -77,12 +77,12 @@ decode_smb(u_char *buf, int len)
 		/* XXX - skip null IPC sessions, etc. */
 		if (user && pass && strlen(user) &&
 		    is_ascii_string(pass, j - 1)) {
-			strlcat(Buf, user, sizeof(Buf));
-			strlcat(Buf, " ", sizeof(Buf));
-			strlcat(Buf, pass, sizeof(Buf));
-			strlcat(Buf, "\n", sizeof(Buf));
+			strlcat(obuf, user, olen);
+			strlcat(obuf, " ", olen);
+			strlcat(obuf, pass, olen);
+			strlcat(obuf, "\n", olen);
 		}
 	}
-	return (strlen(Buf));
+	return (strlen(obuf));
 }
 
