@@ -6,7 +6,7 @@
   Copyright (c) 2000 Anonymous <nobody@localhost>
   Copyright (c) 2000 Dug Song <dugsong@monkey.org>
  
-  $Id: decode_sniffer.c,v 1.2 2000/06/14 13:46:05 dugsong Exp $
+  $Id: decode_sniffer.c,v 1.3 2000/11/06 14:08:43 dugsong Exp $
 */
 
 #include "config.h"
@@ -18,7 +18,7 @@
 #include "decode.h"
 
 int 
-decode_sniffer(u_char *buf, int len)
+decode_sniffer(u_char *buf, int len, u_char *obuf, int olen)
 {
 	u_int i, opcode;
 	
@@ -29,21 +29,21 @@ decode_sniffer(u_char *buf, int len)
 	
 	if (opcode == 260) {
 		if (buf[32] == 0)
-			return (strlcpy(Buf, "[]\n", sizeof(Buf)));
+			return (strlcpy(obuf, "[]\n", olen));
 	}
 	else if (opcode == 261) {
 		if (pletohl(&buf[32]) == -1)
-			return (strlcpy(Buf, "[]\n", sizeof(Buf)));
+			return (strlcpy(obuf, "[]\n", olen));
 	}
 	else return (0);
 	
 	buf[len - 3]= '\0'; strtok(&buf[32], "\r\n");
-	snprintf(Buf, sizeof(Buf), "%s [", &buf[32]);
-	len = strlen(Buf);
-	i = base64_pton(&buf[32], &Buf[len], sizeof(Buf) - len - 3);
-	Buf[len + i] = '\0';
-	strlcat(Buf, "]\n", sizeof(Buf));
+	snprintf(obuf, olen, "%s [", &buf[32]);
+	len = strlen(obuf);
+	i = base64_pton(&buf[32], &obuf[len], olen - len - 3);
+	obuf[len + i] = '\0';
+	strlcat(obuf, "]\n", olen);
 	
-	return (strlen(Buf));
+	return (strlen(obuf));
 }
 
