@@ -5,7 +5,7 @@
   
   Copyright (c) 2000 Dug Song <dugsong@monkey.org>
  
-  $Id: decode_socks.c,v 1.2 2000/06/14 16:16:01 dugsong Exp $
+  $Id: decode_socks.c,v 1.3 2000/11/06 14:08:43 dugsong Exp $
 */
 
 #include "config.h"
@@ -16,7 +16,7 @@
 #include "decode.h"
 
 int
-decode_socks(u_char *buf, int len)
+decode_socks(u_char *buf, int len, u_char *obuf, int olen)
 {
 	u_char *p;
 	int i, n;
@@ -42,7 +42,7 @@ decode_socks(u_char *buf, int len)
 		return (0);
 	
 	memmove(p - 1, p, n); p[n - 1] = '\0';
-	snprintf(Buf, sizeof(Buf), "%s ", p - 1);
+	snprintf(obuf, olen, "%s ", p - 1);
 	p += n;
 	
 	n = *p++;
@@ -50,9 +50,9 @@ decode_socks(u_char *buf, int len)
 		return (0);
 	
 	memmove(p - 1, p, n); p[n - 1] = '\0';
-	strlcat(Buf, p - 1, sizeof(Buf));
-	strlcat(Buf, "\n", sizeof(Buf));
+	strlcat(obuf, p - 1, olen);
+	strlcat(obuf, "\n", olen);
 	
-	return (strlen(Buf));
+	return (strlen(obuf));
 }
 
