@@ -5,7 +5,7 @@
   
   Copyright (c) 2000 Dug Song <dugsong@monkey.org>
   
-  $Id: decode_telnet.c,v 1.3 2000/06/17 19:42:24 dugsong Exp $
+  $Id: decode_telnet.c,v 1.4 2000/11/06 14:08:43 dugsong Exp $
 */
 
 #include "config.h"
@@ -17,7 +17,7 @@
 #include "decode.h"
 
 int
-decode_telnet(u_char *buf, int len)
+decode_telnet(u_char *buf, int len, u_char *obuf, int olen)
 {
 	if ((len = strip_telopts(buf, len)) == 0)
 		return (0);
@@ -28,8 +28,8 @@ decode_telnet(u_char *buf, int len)
 	if (strip_lines(buf, Opt_lines) < 2)
 		return (0);
 	
-	strlcpy(Buf, buf, sizeof(Buf));
+	strlcpy(obuf, buf, olen);
 	
-	return (strlen(Buf));
+	return (strlen(obuf));
 }
 
