@@ -5,7 +5,7 @@
   
   Copyright (c) 2000 Dug Song <dugsong@monkey.org>
   
-  $Id: decode_x11.c,v 1.2 2000/06/14 16:16:01 dugsong Exp $
+  $Id: decode_x11.c,v 1.3 2000/11/06 14:08:43 dugsong Exp $
 */
 
 #include "config.h"
@@ -16,7 +16,7 @@
 #include "decode.h"
 
 int
-decode_x11(u_char *buf, int len)
+decode_x11(u_char *buf, int len, u_char *obuf, int olen)
 {
 	char *p, *q;
 	int i;
@@ -26,16 +26,16 @@ decode_x11(u_char *buf, int len)
 	if (strncmp(p, "MIT-MAGIC-COOKIE-1", 18) != 0 || len < 36)
 		return (0);
 	
-	strlcpy(Buf, "MIT-MAGIC-COOKIE-1 ", sizeof(Buf));
+	strlcpy(obuf, "MIT-MAGIC-COOKIE-1 ", olen);
 	
 	p += 20;
 	len -= 20;
-	q = Buf + 19;
+	q = obuf + 19;
 	
 	for (i = 0; i < 16 && i < len; i++)
 		sprintf(q + (i * 2), "%.2x", (u_char)p[i]);
-	strlcat(Buf, "\n", sizeof(Buf));
+	strlcat(obuf, "\n", olen);
 	
-	return (strlen(Buf));
+	return (strlen(obuf));
 }
 
