@@ -7,7 +7,7 @@
 
   Copyright (c) 2000 Dug Song <dugsong@monkey.org>
 
-  $Id: dsniff.c,v 1.63 2000/06/14 16:16:01 dugsong Exp $
+  $Id: dsniff.c,v 1.68 2000/11/19 21:39:13 dugsong Exp $
 */
 
 #include "config.h"
@@ -17,12 +17,13 @@
 #include <stdlib.h>
 #include <unistd.h>
 #include <signal.h>
-#ifdef HAVE_ERR_H
 #include <err.h>
-#endif
 #include <libnet.h>
 #include <nids.h>
+#include <pcap.h>
 #include "options.h"
+#include "pathnames.h"
+#include "pcaputil.h"
 #include "trigger.h"
 #include "record.h"
 #include "version.h"
@@ -39,26 +40,19 @@ int	Opt_write = 0;
 int	Opt_snaplen = MIN_SNAPLEN;
 int	Opt_lines = MAX_LINES;
 
-static char   *Services = NULL;
-static char   *Savefile = NULL;
-
 void
 usage(void)
 {
 	fprintf(stderr, "Version: " VERSION "\n"
-		"Usage: dsniff [-cdmn] [-i interface] [-s snaplen] "
-		"[-f services] [-r|-w savefile]\n");
+		"Usage: dsniff [-cdmn] [-i interface] [-s snaplen] [-f services]\n"
+		"              [-t trigger[,...]] [-r|-w savefile] [expression]\n");
 	exit(1);
 }
 
 void
 sig_hup(int sig)
 {
-	record_close();
 	trigger_dump();
-	
-	record_init(Savefile);
-	trigger_init(Services);
 }
 
 void
@@ -77,8 +71,11 @@ int
 main(int argc, char *argv[])
 {
 	int c;
+	char *services, *savefile, *triggers;
+
+	services = savefile = triggers = NULL;
 	
-	while ((c = getopt(argc, argv, "cdf:i:mns:r:w:h?V")) != -1) {
+	while ((c = getopt(argc, argv, "cdf:i:mnr:s:t:w:h?V")) != -1) {
 		switch (c) {
 		case 'c':
 			Opt_client = 1;
@@ -87,7 +84,7 @@ main(int argc, char *argv[])
 			Opt_debug++;
 			break;
 		case 'f':
-			Services = optarg;
+			services = optarg;
 			break;
 		case 'i':
 			nids_params.device = optarg;
@@ -98,17 +95,20 @@ main(int argc, char *argv[])
 		case 'n':
 			Opt_dns = 0;
 			break;
+		case 'r':
+			Opt_read = 1;
+			savefile = optarg;
+			break;
 		case 's':
 			if ((Opt_snaplen = atoi(optarg)) == 0)
 				usage();
 			break;
-		case 'r':
-			Opt_read = 1;
-			Savefile = optarg;
+		case 't':
+			triggers = optarg;
 			break;
 		case 'w':
 			Opt_write = 1;
-			Savefile = optarg;
+			savefile = optarg;
 			break;
 		default:
 			usage();
@@ -117,10 +117,10 @@ main(int argc, char *argv[])
 	argc -= optind;
 	argv += optind;
 	
-	if (argc != 0 || (Opt_read && Opt_write))
+	if (Opt_read && Opt_write)
 		usage();
 	
-	if (!record_init(Savefile))
+	if (!record_init(savefile))
 		err(1, "record_init");
 	
 	signal(SIGHUP, sig_hup);
@@ -132,13 +132,26 @@ main(int argc, char *argv[])
 		record_close();
 		exit(0);
 	}
+
+	if (argc != 0)
+		nids_params.pcap_filter = copy_argv(argv);
 	nids_params.scan_num_hosts = 0;
 	nids_params.syslog = null_syslog;
 	
-	if (!nids_init())
+	if (!nids_init()) {
+		record_close();
 		errx(1, "nids_init: %s", nids_errbuf);
-
-	trigger_init(Services);
+	}
+	if (Opt_magic) {
+		trigger_init_magic(DSNIFF_LIBDIR DSNIFF_MAGIC);
+	}
+	if (triggers) {
+		trigger_init_list(triggers);
+	}
+	if (services == NULL) {
+		services = DSNIFF_LIBDIR DSNIFF_SERVICES;
+	}
+	trigger_init_services(services);
 	
 	nids_register_ip(trigger_ip);
 	nids_register_ip(trigger_udp);
@@ -150,12 +163,15 @@ main(int argc, char *argv[])
 	}
 	else nids_register_tcp(trigger_tcp);
 	
-	warnx("listening on %s", nids_params.device);
+	if (nids_params.pcap_filter != NULL) {
+		warnx("listening on %s [%s]", nids_params.device,
+		      nids_params.pcap_filter);
+	}
+	else warnx("listening on %s", nids_params.device);
+	
 	nids_run();
 	
 	/* NOTREACHED */
 	
 	exit(0);
 }
-
-/* 5000. */
