@@ -3,7 +3,7 @@
   
   Copyright (c) 2000 Dug Song <dugsong@monkey.org>
   
-  $Id: hex.c,v 1.2 2000/06/14 16:16:01 dugsong Exp $
+  $Id: hex.c,v 1.4 2000/11/15 05:28:33 dugsong Exp $
 */
 
 #include "config.h"
@@ -15,13 +15,16 @@
 #include "hex.h"
 
 int
-hex_decode(char *src, u_char *dst, int dstsize)
+hex_decode(char *src, int srclen, u_char *dst, int dstlen)
 {
 	char *p, *pe;
 	u_char *q, *qe, ch, cl;
 	
-	pe = src + strlen(src);
-	qe = dst + dstsize;
+	pe = src + srclen;
+	qe = dst + dstlen;
+
+	if (strncmp(src, "0x", 2) == 0)
+		src += 2;
 	
 	for (p = src, q = dst; p < pe && q < qe && isxdigit((int)*p); p += 2) {
 		ch = tolower(p[0]);
