@@ -8,7 +8,7 @@
   
   Copyright (c) 1999 Dug Song <dugsong@monkey.org>
   
-  $Id: macof.c,v 1.11 2000/06/14 06:09:59 dugsong Exp $
+  $Id: macof.c,v 1.13 2000/09/21 03:04:41 dugsong Exp $
 */
 
 #include "config.h"
@@ -17,9 +17,7 @@
 #include <sys/param.h>
 #include <stdio.h>
 #include <string.h>
-#ifdef HAVE_ERR_H
 #include <err.h>
-#endif
 #include <libnet.h>
 #include <pcap.h>
 
@@ -61,6 +59,7 @@ main(int argc, char *argv[])
 	u_char sha[ETHER_ADDR_LEN], tha[ETHER_ADDR_LEN];
 	in_addr_t src, dst;
 	u_short sport, dport;
+	u_int32_t seq;
 	u_char pkt[ETH_H + IP_H + TCP_H];
 	
 	while ((c = getopt(argc, argv, "vs:d:e:x:y:i:n:h?V")) != -1) {
@@ -124,14 +123,15 @@ main(int argc, char *argv[])
 		
 		if (Dport != 0) dport = Dport;
 		else dport = libnet_get_prand(PRu16);
+
+		seq = libnet_get_prand(PRu32);
 		
 		libnet_build_ethernet(tha, sha, ETHERTYPE_IP, NULL, 0, pkt);
 		
 		libnet_build_ip(TCP_H, 0, libnet_get_prand(PRu16), 0, 64,
 				IPPROTO_TCP, src, dst, NULL, 0, pkt + ETH_H);
 		
-		libnet_build_tcp(sport, dport, libnet_get_prand(PRu32),
-				 libnet_get_prand(PRu32), TH_SYN, 1024,
+		libnet_build_tcp(sport, dport, seq, 0, TH_SYN, 512,
 				 0, NULL, 0, pkt + ETH_H + IP_H);
 		
 		libnet_do_checksum(pkt + ETH_H, IPPROTO_IP, IP_H);
@@ -140,10 +140,12 @@ main(int argc, char *argv[])
 		if (libnet_write_link_layer(llif, Intf, pkt, sizeof(pkt)) < 0)
 			errx(1, "write");
 
-		fprintf(stderr, "macof: %s -> ",
+		fprintf(stderr, "%s ",
 			ether_ntoa((struct ether_addr *)sha));
-		fprintf(stderr, "%s\n",
-			ether_ntoa((struct ether_addr *)tha));
+		fprintf(stderr, "%s %s.%d > %s.%d: S %u:%u(0) win 512\n",
+			ether_ntoa((struct ether_addr *)tha),
+			libnet_host_lookup(Src, 0), sport,
+			libnet_host_lookup(Dst, 0), dport, seq, seq);
 	}
 	exit(0);
 }
