@@ -5,13 +5,13 @@
   
   Copyright (c) 2000 Dug Song <dugsong@monkey.org>
   
-  $Id: magic.h,v 1.1 2000/06/14 00:29:55 dugsong Exp $
+  $Id: magic.h,v 1.2 2000/11/19 21:39:40 dugsong Exp $
 */
 
 #ifndef MAGIC_H
 #define MAGIC_H
 
-int	 magic_init(void);
+void	 magic_init(char *filename);
 
 char	*magic_match(u_char *buf, int len);
 
