@@ -5,7 +5,7 @@
   
   Copyright (c) 2000 Dug Song <dugsong@monkey.org>
   
-  $Id: record.h,v 1.1 2000/05/16 17:31:15 dugsong Exp $
+  $Id: record.h,v 1.2 2000/06/14 06:10:00 dugsong Exp $
 */
 
 #ifndef RECORD_H
@@ -13,7 +13,7 @@
 
 int	record_init(char *file);
 
-int	record(u_long src, u_long dst, int proto, u_short sport, u_short dport,
+int	record(u_int32_t src, u_int32_t dst, int proto, u_short sport, u_short dport,
 	       char *name, u_char *buf, int len);
 
 void	record_dump(void);
