@@ -3,7 +3,7 @@
 
   Copyright (c) 2000 Dug Song <dugsong@monkey.org>
   
-  $Id: rpc.c,v 1.6 2000/06/14 06:43:32 dugsong Exp $
+  $Id: rpc.c,v 1.7 2000/12/15 20:13:29 dugsong Exp $
 */
 
 #include "config.h"
@@ -68,22 +68,22 @@ int
 rpc_decode(u_char *buf, int len, struct rpc_msg *msg)
 {
 	XDR xdrs;
-	u_int32_t *p, fraghdr;
-	u_char *tmp;
+	u_int32_t fraghdr;
+	u_char *p, *tmp;
 	int stat, tmplen;
 
 	if (len < 20)
 		return (0);
 	
-	p = (u_int32_t *)&buf[4];
+	p = buf + 4;
 
 	/* If not recognizably RPC, try TCP record defragmentation */
-	if (ntohl(*p) != CALL && ntohl(*p) != REPLY) {
+	if (pntohl(p) != CALL && pntohl(p) != REPLY) {
 		tmp = buf;
 		tmplen = 0;
 		
 		for (;;) {
-			fraghdr = ntohl(*(u_int32_t *)tmp);
+			fraghdr = pntohl(tmp);
 			
 			if (FRAGLEN(fraghdr) + 4 > len)
 				return (0);
@@ -104,6 +104,8 @@ rpc_decode(u_char *buf, int len, struct rpc_msg *msg)
 		len = tmplen;
 	}
 	/* Decode RPC message. */
+	memset(msg, 0, sizeof(*msg));
+	
 	if (ntohl(((struct rpc_msg *)buf)->rm_direction) == CALL) {
 		xdrmem_create(&xdrs, buf, len, XDR_DECODE);
 		
