@@ -3,7 +3,7 @@
 
   Copyright (c) 2000 Dug Song <dugsong@monkey.org>
   
-  $Id: tcp_raw.c,v 1.6 2000/06/14 06:48:39 dugsong Exp $
+  $Id: tcp_raw.c,v 1.8 2000/08/28 01:30:22 dugsong Exp $
 */
 
 #include "config.h"
@@ -11,9 +11,7 @@
 #include <sys/types.h>
 #include <sys/uio.h>
 #include <time.h>
-#ifdef HAVE_ERR_H
 #include <err.h>
-#endif
 #include <libnet.h>
 #include "options.h"
 #include "tcp_raw.h"
@@ -119,7 +117,7 @@ tcp_raw_reassemble(struct tcp_conn *conn, int minlen)
 }
 
 struct iovec *
-tcp_raw_input(struct ip *ip, struct tcphdr *tcp, int len)
+tcp_raw_input(struct libnet_ip_hdr *ip, struct libnet_tcp_hdr *tcp, int len)
 {
 	struct tha tha;
 	struct tcp_conn *conn;
