@@ -3,7 +3,7 @@
 
   Copyright (c) 2000 Dug Song <dugsong@monkey.org>
   
-  $Id: trigger.c,v 1.14 2000/06/17 19:15:10 dugsong Exp $
+  $Id: trigger.c,v 1.19 2000/11/19 21:44:29 dugsong Exp $
 */
 
 #include "config.h"
@@ -11,17 +11,15 @@
 #include <sys/types.h>
 #include <sys/uio.h>
 #include <stdlib.h>
-#ifdef HAVE_ERR_H
 #include <err.h>
-#endif
 #include <libnet.h>
 #include <nids.h>
-#include "options.h"
 #include "decode.h"
+#include "magic.h"
+#include "options.h"
+#include "pathnames.h"
 #include "record.h"
 #include "tcp_raw.h"
-#include "magic.h"
-#include "pathnames.h"
 #include "trigger.h"
 
 struct trigger {
@@ -39,6 +37,8 @@ static u_int		udp_cnt = 0;
 static u_int		tcp_cnt = 0;
 static u_int		rpc_cnt = 0;
 
+static char		obuf[4096];
+
 static int
 trigger_compare(const void *a, const void *b)
 {
@@ -185,6 +185,26 @@ trigger_set_rpc(int num, char *name)
 	return (1);
 }
 
+int
+trigger_set(char *proto, int num, char *name)
+{
+	if (strcasecmp(proto, "ip") == 0) {
+		return (trigger_set_ip(num, name));
+	}
+	else if (strcasecmp(proto, "udp") == 0) {
+		return (trigger_set_udp(num, name));
+	}
+	else if (strcasecmp(proto, "tcp") == 0) {
+		return (trigger_set_tcp(num, name));
+	}
+	else if (strcasecmp(proto, "rpc") == 0) {
+		return (trigger_set_rpc(num, name));
+	}
+	else warnx("trigger_set: unknown protocol %s", proto);
+
+	return (0);
+}
+
 static struct trigger *
 trigger_set_magic(int proto, int num, u_char *buf, int len)
 {
@@ -230,7 +250,7 @@ trigger_dump(void)
 		warn("trigger_dump: couldn't open " DSNIFF_SERVICES);
 		return;
 	}
-	fprintf(f, "# $Id: trigger.c,v 1.14 2000/06/17 19:15:10 dugsong Exp $\n"
+	fprintf(f, "# $Id: trigger.c,v 1.19 2000/11/19 21:44:29 dugsong Exp $\n"
 		"#\n# Network services, dsniff style\n#\n");
 	
 	for (i = 0; i < ip_cnt; i++) {
@@ -253,7 +273,7 @@ trigger_dump(void)
 }
 	
 void
-trigger_ip(struct ip *ip)
+trigger_ip(struct libnet_ip_hdr *ip)
 {
 	struct trigger *t, tr;
 	u_char *buf;
@@ -274,18 +294,18 @@ trigger_ip(struct ip *ip)
 		warnx("trigger_ip: decoding proto %d as %s",
 		      tr.num, t->decode->dc_name);
 	
-	if ((len = t->decode->dc_func(buf, len)) > 0) {
+	if ((len = t->decode->dc_func(buf, len, obuf, sizeof(obuf))) > 0) {
 		record(ip->ip_src.s_addr, ip->ip_dst.s_addr, ip->ip_p,
-		       0, 0, t->decode->dc_name, Buf, len);
+		       0, 0, t->decode->dc_name, obuf, len);
 	}		
 }
 
 /* libnids needs a nids_register_udp()... */
 void
-trigger_udp(struct ip *ip)
+trigger_udp(struct libnet_ip_hdr *ip)
 {
 	struct trigger *t, tr;
-	struct udphdr *udp;
+	struct libnet_udp_hdr *udp;
 	u_char *buf;
 	int len, ip_hl = ip->ip_hl * 4;
 	
@@ -295,7 +315,7 @@ trigger_udp(struct ip *ip)
 		return;
 
 	buf = (u_char *)ip + ip_hl;
-	udp = (struct udphdr *)buf;
+	udp = (struct libnet_udp_hdr *)buf;
 	
 	if (len != ntohs(udp->uh_ulen))
 		return;
@@ -320,10 +340,10 @@ trigger_udp(struct ip *ip)
 		warnx("trigger_udp: decoding port %d as %s",
 		      tr.num, t->decode->dc_name);
 	
-	if ((len = t->decode->dc_func(buf, len)) > 0) {
+	if ((len = t->decode->dc_func(buf, len, obuf, sizeof(obuf))) > 0) {
 		record(ip->ip_src.s_addr, ip->ip_dst.s_addr, IPPROTO_UDP,
 		       ntohs(udp->uh_sport), ntohs(udp->uh_dport),
-		       t->decode->dc_name, Buf, len);
+		       t->decode->dc_name, obuf, len);
 	}
 }
 
@@ -351,10 +371,11 @@ trigger_tcp_half(struct tuple4 *addr, struct half_stream *hs,
 			warnx("trigger_tcp: decoding port %d as %s",
 			      addr->dest, t->decode->dc_name);
 		
-		if ((len = t->decode->dc_func(buf, len)) > 0) {
+		if ((len = t->decode->dc_func(buf, len,
+					      obuf, sizeof(obuf))) > 0) {
 			record(addr->saddr, addr->daddr, IPPROTO_TCP,
 			       addr->source, addr->dest, t->decode->dc_name,
-			       Buf, len);
+			       obuf, len);
 		}
 	}
 	hs->collect = 0;
@@ -413,10 +434,10 @@ trigger_tcp(struct tcp_stream *ts, void **conn_save)
 }
 
 void
-trigger_tcp_raw(struct ip *ip)
+trigger_tcp_raw(struct libnet_ip_hdr *ip)
 {
 	struct trigger *t, tr;
-	struct tcphdr *tcp;
+	struct libnet_tcp_hdr *tcp;
 	struct iovec *iov;
 	int len, ip_hl = ip->ip_hl * 4;
 	
@@ -425,7 +446,7 @@ trigger_tcp_raw(struct ip *ip)
 	if (ip->ip_p != IPPROTO_TCP || len < sizeof(*tcp))
 		return;
 
-	tcp = (struct tcphdr *)((u_char *)ip + ip_hl);
+	tcp = (struct libnet_tcp_hdr *)((u_char *)ip + ip_hl);
 	
 	tr.num = ntohs(tcp->th_dport);
 	
@@ -450,13 +471,14 @@ trigger_tcp_raw(struct ip *ip)
 			warnx("trigger_tcp_raw: decoding port %d as %s",
 			      tr.num, t->decode->dc_name);
 		
-		len = t->decode->dc_func(iov->iov_base, iov->iov_len);
+		len = t->decode->dc_func(iov->iov_base, iov->iov_len,
+					 obuf, sizeof(obuf));
 		
 		if (len > 0) {
 			record(ip->ip_src.s_addr, ip->ip_dst.s_addr,
 			       IPPROTO_TCP, ntohs(tcp->th_sport),
 			       ntohs(tcp->th_dport), t->decode->dc_name,
-			       Buf, len);
+			       obuf, len);
 		}
 	}
 	free(iov->iov_base);
@@ -483,9 +505,10 @@ trigger_tcp_raw_callback(in_addr_t src, in_addr_t dst,
 			      "decoding port %d as %s",
 			      tr.num, t->decode->dc_name);
 		
-		if ((len = t->decode->dc_func(buf, len)) > 0) {
+		if ((len = t->decode->dc_func(buf, len,
+					      obuf, sizeof(obuf))) > 0) {
 			record(src, dst, IPPROTO_TCP, sport, dport,
-			       t->decode->dc_name, Buf, len);
+			       t->decode->dc_name, obuf, len);
 		}
 	}
 }
@@ -518,61 +541,44 @@ trigger_rpc(int program, int proto, int port)
 }
 	
 void
-trigger_init(char *services)
+trigger_init_magic(char *filename)
+{
+	magic_init(filename);
+}
+
+void
+trigger_init_list(char *list)
+{
+	char *name, *port, *proto = NULL;
+
+	while ((name = strsep(&list, ",")) != NULL) {
+		if ((port = strsep(&name, "/")) == NULL ||
+		    (proto = strsep(&name, "=")) == NULL) {
+			errx(1, "trigger_init_list: parse error");
+		}
+		trigger_set(proto, atoi(port), name);
+	}
+}
+
+void
+trigger_init_services(char *services)
 {
 	FILE *f;
 	char *name, *port, *proto, line[1024];
-	int num;
-
-	ip_cnt = 0;
-	udp_cnt = 0;
-	tcp_cnt = 0;
-	rpc_cnt = 0;
 	
-	memset((char *)&ip_triggers, 0, sizeof(ip_triggers));
-	memset((char *)&udp_triggers, 0, sizeof(udp_triggers));
-	memset((char *)&tcp_triggers, 0, sizeof(tcp_triggers));
-	memset((char *)&rpc_triggers, 0, sizeof(rpc_triggers));
-
-	if (Opt_magic) {
-		if (!magic_init())
-			exit(1);
-		return;
-	}
-	if (services == NULL) {
-		if ((f = fopen(DSNIFF_LIBDIR DSNIFF_SERVICES, "r")) == NULL)
-			if ((f = fopen(DSNIFF_SERVICES, "r")) == NULL)
-				err(1, "trigger_init: fopen");
-	}
-	else if ((f = fopen(services, "r")) == NULL)
-		errx(1, "trigger_init: couldn't open %s", services);
+	if ((f = fopen(services, "r")) == NULL)
+		errx(1, "couldn't open %s", services);
 	
 	while (fgets(line, sizeof(line), f) != NULL) {
 		if (line[0] == '#' || line[0] == '\n')
 			continue;
 		
-		name = strtok(line, " \t");
-		port = strtok(NULL, " \t/");
-		proto = strtok(NULL, " \t#\n");
-		
-		if (!name || !port || !proto)
+		if ((name = strtok(line, " \t")) == NULL ||
+		    (port = strtok(NULL, " \t/")) == NULL ||
+		    (proto = strtok(NULL, " \t#\n")) == NULL) {
 			continue;
-		
-		if ((num = atoi(port)) == 0)
-			continue;
-		
-		if (strcasecmp(proto, "ip") == 0) {
-			trigger_set_ip(num, name);
-		}
-		else if (strcasecmp(proto, "udp") == 0) {
-			trigger_set_udp(num, name);
-		}
-		else if (strcasecmp(proto, "tcp") == 0) {
-			trigger_set_tcp(num, name);
-		}
-		else if (strcasecmp(proto, "rpc") == 0) {
-			trigger_set_rpc(num, name);
 		}
+		trigger_set(proto, atoi(port), name);
 	}
 	fclose(f);
 }
